"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseCommand = exports.gasOptions = void 0;
const contractkit_1 = require("@celo/contractkit");
const celo_tokens_1 = require("@celo/contractkit/lib/celo-tokens");
const wallet_hsm_azure_1 = require("@celo/wallet-hsm-azure");
const wallet_ledger_1 = require("@celo/wallet-ledger");
const wallet_local_1 = require("@celo/wallet-local");
const command_1 = require("@oclif/command");
const chalk_1 = __importDefault(require("chalk"));
const net_1 = __importDefault(require("net"));
const web3_1 = __importDefault(require("web3"));
const config_1 = require("./utils/config");
const helpers_1 = require("./utils/helpers");
exports.gasOptions = Object.assign(Object.assign({ auto: 'auto', Auto: 'auto' }, (0, helpers_1.enumEntriesDupWithLowercase)(Object.entries(contractkit_1.Token))), (0, helpers_1.enumEntriesDupWithLowercase)(Object.entries(contractkit_1.StableToken)));
// tslint:disable-next-line:max-classes-per-file
class BaseCommand extends command_1.Command {
    constructor() {
        super(...arguments);
        // This specifies whether the node needs to be synced before the command
        // can be run. In most cases, this should be `true`, so that's the default.
        // For commands that don't require the node is synced, add the following line
        // to its definition:
        //   requireSynced = false
        this.requireSynced = true;
        this._web3 = null;
        this._kit = null;
    }
    get web3() {
        if (!this._web3) {
            const res = this.parse();
            const nodeUrl = (res.flags && res.flags.node) || (0, config_1.getNodeUrl)(this.config.configDir);
            this._web3 =
                nodeUrl && nodeUrl.endsWith('.ipc')
                    ? new web3_1.default(new web3_1.default.providers.IpcProvider(nodeUrl, net_1.default))
                    : new web3_1.default(nodeUrl);
        }
        return this._web3;
    }
    newWeb3() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse();
            const nodeUrl = (res.flags && res.flags.node) || (0, config_1.getNodeUrl)(this.config.configDir);
            return nodeUrl && nodeUrl.endsWith('.ipc')
                ? new web3_1.default(new web3_1.default.providers.IpcProvider(nodeUrl, net_1.default))
                : new web3_1.default(nodeUrl);
        });
    }
    get kit() {
        if (!this._kit) {
            this._kit = (0, contractkit_1.newKitFromWeb3)(this.web3);
            this._kit.connection.wallet = this._wallet;
        }
        const res = this.parse();
        if (res.flags && res.flags.privateKey && !res.flags.useLedger && !res.flags.useAKV) {
            this._kit.connection.addAccount(res.flags.privateKey);
        }
        return this._kit;
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.requireSynced) {
                yield (0, helpers_1.requireNodeIsSynced)(this.web3);
            }
            const res = this.parse();
            if (res.flags.globalHelp) {
                console.log(chalk_1.default.red.bold('GLOBAL OPTIONS'));
                Object.entries(BaseCommand.flags).forEach(([name, flag]) => {
                    console.log(chalk_1.default.black(`  --${name}`).padEnd(40) + chalk_1.default.gray(`${flag.description}`));
                });
                process.exit(0);
            }
            if (res.flags.useLedger) {
                let transport;
                try {
                    // Importing for ledger uses only fixes running jest tests
                    const TransportNodeHid = (yield Promise.resolve().then(() => __importStar(require('@ledgerhq/hw-transport-node-hid')))).default;
                    transport = yield TransportNodeHid.open('');
                    const derivationPathIndexes = res.raw.some((value) => value.flag === 'ledgerCustomAddresses')
                        ? JSON.parse(res.flags.ledgerCustomAddresses)
                        : Array.from(Array(res.flags.ledgerAddresses).keys());
                    console.log('Retrieving derivation Paths', derivationPathIndexes);
                    let ledgerConfirmation = wallet_ledger_1.AddressValidation.never;
                    if (res.flags.ledgerConfirmAddress) {
                        ledgerConfirmation = wallet_ledger_1.AddressValidation.everyTransaction;
                    }
                    this._wallet = yield (0, wallet_ledger_1.newLedgerWalletWithSetup)(transport, derivationPathIndexes, undefined, ledgerConfirmation);
                }
                catch (err) {
                    console.log('Check if the ledger is connected and logged.');
                    throw err;
                }
            }
            else if (res.flags.useAKV) {
                try {
                    const akvWallet = new wallet_hsm_azure_1.AzureHSMWallet(res.flags.azureVaultName);
                    yield akvWallet.init();
                    console.log(`Found addresses: ${akvWallet.getAccounts()}`);
                    this._wallet = akvWallet;
                }
                catch (err) {
                    console.log(`Failed to connect to AKV ${err}`);
                    throw err;
                }
            }
            else {
                this._wallet = new wallet_local_1.LocalWallet();
            }
            if (res.flags.from) {
                this.kit.defaultAccount = res.flags.from;
            }
            const gasCurrencyConfig = res.flags.gasCurrency
                ? exports.gasOptions[res.flags.gasCurrency]
                : (0, config_1.getGasCurrency)(this.config.configDir);
            const setStableTokenGas = (stable) => __awaiter(this, void 0, void 0, function* () {
                yield this.kit.setFeeCurrency(celo_tokens_1.stableTokenInfos[stable].contract);
            });
            if (Object.keys(contractkit_1.StableToken).includes(gasCurrencyConfig)) {
                yield setStableTokenGas(contractkit_1.StableToken[gasCurrencyConfig]);
            }
            else if (gasCurrencyConfig === exports.gasOptions.auto && this.kit.defaultAccount) {
                const balances = yield this.kit.getTotalBalance(this.kit.defaultAccount);
                if (balances.CELO.isZero()) {
                    const stables = Object.entries(contractkit_1.StableToken);
                    for (const stable of stables) {
                        const stableName = stable[0];
                        const stableToken = stable[1];
                        // has balance
                        if (balances[stableName] && !balances[stableName].isZero()) {
                            yield setStableTokenGas(stableToken);
                            break;
                        }
                    }
                }
            }
        });
    }
    finally(arg) {
        try {
            this.kit.connection.stop();
        }
        catch (error) {
            this.log(`Failed to close the connection: ${error}`);
        }
        return super.finally(arg);
    }
}
exports.BaseCommand = BaseCommand;
BaseCommand.flags = {
    privateKey: command_1.flags.string({
        char: 'k',
        description: 'Use a private key to sign local transactions with',
        hidden: true,
    }),
    node: command_1.flags.string({
        char: 'n',
        description: "URL of the node to run commands against (defaults to 'http://localhost:8545')",
        hidden: true,
        parse: (nodeUrl) => {
            switch (nodeUrl) {
                case 'local':
                case 'localhost':
                    return 'http://localhost:8545';
                case 'baklava':
                    return 'https://baklava-forno.celo-testnet.org';
                case 'alfajores':
                    return 'https://alfajores-forno.celo-testnet.org';
                case 'mainnet':
                case 'forno':
                    return 'https://forno.celo.org';
                default:
                    return nodeUrl;
            }
        },
    }),
    gasCurrency: command_1.flags.enum({
        options: Object.keys(exports.gasOptions),
        description: "Use a specific gas currency for transaction fees (defaults to 'auto' which uses whatever feeCurrency is available)",
        hidden: true,
    }),
    useLedger: command_1.flags.boolean({
        default: false,
        hidden: true,
        description: 'Set it to use a ledger wallet',
    }),
    ledgerAddresses: command_1.flags.integer({
        default: 1,
        hidden: true,
        exclusive: ['ledgerCustomAddresses'],
        description: 'If --useLedger is set, this will get the first N addresses for local signing',
    }),
    ledgerCustomAddresses: command_1.flags.string({
        default: '[0]',
        hidden: true,
        exclusive: ['ledgerAddresses'],
        description: 'If --useLedger is set, this will get the array of index addresses for local signing. Example --ledgerCustomAddresses "[4,99]"',
    }),
    useAKV: command_1.flags.boolean({
        default: false,
        hidden: true,
        description: 'Set it to use an Azure KeyVault HSM',
    }),
    azureVaultName: command_1.flags.string({
        hidden: true,
        description: 'If --useAKV is set, this is used to connect to the Azure KeyVault',
    }),
    ledgerConfirmAddress: command_1.flags.boolean({
        default: false,
        hidden: true,
        description: 'Set it to ask confirmation for the address of the transaction from the ledger',
    }),
    globalHelp: command_1.flags.boolean({
        default: false,
        hidden: false,
        description: 'View all available global flags',
    }),
};
//# sourceMappingURL=base.js.map