"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class Deauthorize extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(Deauthorize);
            const accounts = yield this.kit.contracts.getAccounts();
            if (res.flags.role !== 'attestation') {
                this.error(`Invalid role provided`);
                return;
            }
            const attestationSigner = yield accounts.getAttestationSigner(res.flags.from);
            if (res.flags.signer !== attestationSigner) {
                this.error(`Invalid signer argument: ${res.flags.signer}. The current signer for this role is: ${attestationSigner}`);
                return;
            }
            const tx = yield accounts.removeAttestationSigner();
            yield (0, cli_1.displaySendTx)('deauthorizeTx', tx);
        });
    }
}
exports.default = Deauthorize;
Deauthorize.description = "Remove an account's authorized attestation signer role.";
Deauthorize.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({ required: true }), role: command_1.flags.string({
        char: 'r',
        options: ['attestation'],
        description: 'Role to remove',
        required: true,
    }), signer: command_2.Flags.address({ required: true }) });
Deauthorize.args = [];
Deauthorize.examples = [
    'deauthorize --from 0x5409ED021D9299bf6814279A6A1411A7e866A631 --role attestation --signer 0x6ecbe1db9ef729cbe972c83fb886247691fb6beb',
];
//# sourceMappingURL=deauthorize.js.map