"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const command_1 = require("../../utils/command");
class GetPaymentDelegation extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(GetPaymentDelegation);
            this.kit.defaultAccount = res.flags.account;
            const accounts = yield this.kit.contracts.getAccounts();
            console.log('Payment delegation beneficiary and fraction are: \n');
            const retval = yield accounts.getPaymentDelegation(res.flags.account);
            const beneficiary = retval[0];
            // translate fixidity value to human readable fraction
            const fraction = new bignumber_js_1.default(retval[1]).shiftedBy(-24).toNumber();
            console.log(beneficiary, fraction);
        });
    }
}
exports.default = GetPaymentDelegation;
GetPaymentDelegation.description = "Get the payment delegation account beneficiary and fraction allocated from a validator's payment each epoch. The fraction cannot be greater than 1.";
GetPaymentDelegation.flags = Object.assign(Object.assign(Object.assign({}, base_1.BaseCommand.flags), { account: command_1.Flags.address({ required: true }) }), cli_ux_1.cli.table.flags());
GetPaymentDelegation.args = [];
GetPaymentDelegation.examples = ['get-payment-delegation --account 0x5409ed021d9299bf6814279a6a1411a7e866a631'];
//# sourceMappingURL=get-payment-delegation.js.map