"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const account_1 = require("@celo/cryptographic-utils/lib/account");
const address_1 = require("@celo/utils/lib/address");
const util_1 = require("@ethereumjs/util");
const command_1 = require("@oclif/command");
const fs = __importStar(require("fs-extra"));
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
const ETHEREUM_DERIVATION_PATH = "m/44'/60'/0'";
class NewAccount extends base_1.BaseCommand {
    constructor() {
        super(...arguments);
        this.requireSynced = false;
    }
    static languageOptions(language) {
        if (language) {
            // @ts-ignore
            const enumLanguage = account_1.MnemonicLanguages[language];
            return enumLanguage;
        }
        return undefined;
    }
    static sanitizeDerivationPath(derivationPath) {
        if (derivationPath) {
            derivationPath = derivationPath.endsWith('/') ? derivationPath.slice(0, -1) : derivationPath;
        }
        return derivationPath !== 'eth' ? derivationPath : ETHEREUM_DERIVATION_PATH;
    }
    static readFile(file) {
        if (!file) {
            return undefined;
        }
        if (fs.pathExistsSync(file)) {
            return fs
                .readFileSync(file)
                .toString()
                .replace(/(\r\n|\n|\r)/gm, '');
        }
        throw new Error(`Invalid path: ${file}`);
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(NewAccount);
            let mnemonic = NewAccount.readFile(res.flags.mnemonicPath);
            if (mnemonic) {
                mnemonic = (0, account_1.normalizeMnemonic)(mnemonic);
                if (!(0, account_1.validateMnemonic)(mnemonic)) {
                    throw Error('Invalid mnemonic. Should be a bip39 mnemonic');
                }
            }
            else {
                mnemonic = yield (0, account_1.generateMnemonic)(account_1.MnemonicStrength.s256_24words, NewAccount.languageOptions(res.flags.language));
            }
            const derivationPath = NewAccount.sanitizeDerivationPath(res.flags.derivationPath);
            const passphrase = NewAccount.readFile(res.flags.passphrasePath);
            const keys = yield (0, account_1.generateKeys)(mnemonic, passphrase, res.flags.changeIndex, res.flags.addressIndex, undefined, derivationPath);
            const accountAddress = (0, util_1.toChecksumAddress)((0, address_1.privateKeyToAddress)(keys.privateKey));
            this.log('This is not being stored anywhere. Save the mnemonic somewhere to use this account at a later point.\n');
            (0, cli_1.printValueMap)(Object.assign({ mnemonic, accountAddress }, keys));
        });
    }
}
exports.default = NewAccount;
NewAccount.description = "Creates a new account locally using the Celo Derivation Path (m/44'/52752'/0/changeIndex/addressIndex) and print out the key information. Save this information for local transaction signing or import into a Celo node. Ledger: this command has been tested swapping mnemonics with the Ledger successfully (only supports english)";
NewAccount.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { passphrasePath: command_1.flags.string({
        description: 'Path to a file that contains the BIP39 passphrase to combine with the mnemonic specified using the mnemonicPath flag and the index specified using the addressIndex flag. Every passphrase generates a different private key and wallet address.',
    }), changeIndex: command_1.flags.integer({
        default: 0,
        description: 'Choose the change index for the derivation path',
    }), addressIndex: command_1.flags.integer({
        default: 0,
        description: 'Choose the address index for the derivation path',
    }), language: command_1.flags.string({
        options: [
            'chinese_simplified',
            'chinese_traditional',
            'english',
            'french',
            'italian',
            'japanese',
            'korean',
            'spanish',
        ],
        default: 'english',
        description: "Language for the mnemonic words. **WARNING**, some hardware wallets don't support other languages",
    }), mnemonicPath: command_1.flags.string({
        description: 'Instead of generating a new mnemonic (seed phrase), use the user-supplied mnemonic instead. Path to a file that contains all the mnemonic words separated by a space (example: "word1 word2 word3 ... word24"). If the words are a language other than English, the --language flag must be used. Only BIP39 mnemonics are supported',
    }), derivationPath: command_1.flags.string({
        description: "Choose a different derivation Path (Celo's default is \"m/44'/52752'/0'\"). Use \"eth\" as an alias of the Ethereum derivation path (\"m/44'/60'/0'\"). Recreating the same account requires knowledge of the mnemonic, passphrase (if any), and the derivation path",
    }) });
NewAccount.examples = [
    'new',
    'new --passphrasePath myFolder/my_passphrase_file',
    'new --language spanish',
    'new --passphrasePath some_folder/my_passphrase_file --language japanese --addressIndex 5',
    'new --passphrasePath some_folder/my_passphrase_file --mnemonicPath some_folder/my_mnemonic_file --addressIndex 5',
];
//# sourceMappingURL=new.js.map