"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const name_1 = require("@celo/identity/lib/offchain/accessors/name");
const address_1 = require("@celo/utils/lib/address");
const command_1 = require("@oclif/command");
const cli_1 = require("../../utils/cli");
const off_chain_data_1 = require("../../utils/off-chain-data");
class OffchainWrite extends off_chain_data_1.OffchainDataCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags: { encryptTo, name, privateDEK, privateKey }, } = this.parse(OffchainWrite);
            if (encryptTo && privateDEK && privateKey) {
                this.kit.defaultAccount = (0, address_1.privateKeyToAddress)(privateKey);
                this.kit.addAccount(privateDEK);
                const nameSchema = new name_1.PrivateNameAccessor(this.offchainDataWrapper);
                yield nameSchema.write({ name }, [encryptTo]);
            }
            else {
                if (!(yield (0, cli_1.binaryPrompt)('This operation will make your name public. Are you sure you want to do that?', true))) {
                    return;
                }
                const nameSchema = new name_1.PublicNameAccessor(this.offchainDataWrapper);
                yield nameSchema.write({ name });
            }
        });
    }
}
exports.default = OffchainWrite;
OffchainWrite.description = 'DEV: Writes a name to offchain storage';
OffchainWrite.flags = Object.assign(Object.assign({}, off_chain_data_1.OffchainDataCommand.flags), { name: command_1.flags.string({ required: true }), privateKey: command_1.flags.string({ required: true }), 
    // private accessor parameters
    privateDEK: command_1.flags.string({ dependsOn: ['privateKey', 'encryptTo'] }), encryptTo: command_1.flags.string({ dependsOn: ['privateKey', 'privateDEK'] }) });
OffchainWrite.args = [];
OffchainWrite.examples = [
    'offchain-write --name test-account --privateKey 0x...',
    'offchain-write --name test-account --privateKey 0x...  privateDEK 0x... --encryptTo 0x...',
];
//# sourceMappingURL=offchain-write.js.map