"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const account_1 = require("@celo/cryptographic-utils/lib/account");
const address_1 = require("@celo/utils/lib/address");
const util_1 = require("@ethereumjs/util");
const command_1 = require("@oclif/command");
const cli_1 = require("../../utils/cli");
const new_1 = __importDefault(require("./new"));
// TODO: This command should be prune in the future after all accounts had been migrated
class RecoverOld extends new_1.default {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(RecoverOld);
            let mnemonic = new_1.default.readFile(res.flags.mnemonicPath);
            if (mnemonic) {
                mnemonic = (0, account_1.normalizeMnemonic)(mnemonic);
                if (!(0, account_1.validateMnemonic)(mnemonic)) {
                    throw Error('Invalid mnemonic. Should be a bip39 mnemonic');
                }
            }
            else {
                throw Error('Must provide a valid bip39 mnemonic');
            }
            const derivationPath = new_1.default.sanitizeDerivationPath(res.flags.derivationPath);
            const passphrase = new_1.default.readFile(res.flags.passphrasePath);
            const seed32 = yield (0, account_1.generateSeed)(mnemonic, passphrase, undefined, 32);
            const keys = (0, account_1.generateKeysFromSeed)(seed32, res.flags.addressIndex, res.flags.changeIndex, derivationPath);
            const accountAddress = (0, util_1.toChecksumAddress)((0, address_1.privateKeyToAddress)(keys.privateKey));
            (0, cli_1.printValueMap)(Object.assign({ accountAddress }, keys));
        });
    }
}
exports.default = RecoverOld;
RecoverOld.description = 'Recovers the Valora old account and print out the key information. The old Valora app (in a beta state) generated the user address using a seed of 32 bytes, instead of 64 bytes. As the app fixed that, some old accounts were left with some funds. This command allows the user to recover those funds.';
RecoverOld.flags = Object.assign(Object.assign({}, new_1.default.flags), { mnemonicPath: command_1.flags.string({
        required: true,
        description: 'Path to a file that contains all the mnemonic words separated by a space (example: "word1 word2 word3 ... word24"). If the words are a language other than English, the --language flag must be used. Only BIP39 mnemonics are supported',
    }) });
RecoverOld.examples = [
    'recover-old --mnemonicPath some_folder/my_mnemonic_file',
    'recover-old --mnemonicPath some_folder/my_mnemonic_file --passphrasePath myFolder/my_passphrase_file',
    'recover-old --mnemonicPath some_folder/my_mnemonic_file --language spanish',
    'recover-old --mnemonicPath some_folder/my_mnemonic_file --passphrasePath some_folder/my_passphrase_file --language japanese --addressIndex 5',
    'recover-old --mnemonicPath some_folder/my_mnemonic_file --passphrasePath some_folder/my_passphrase_file --addressIndex 5',
];
//# sourceMappingURL=recover-old.js.map