"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const address_1 = require("@celo/utils/lib/address");
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class RegisterDataEncryptionKey extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(RegisterDataEncryptionKey);
            this.kit.defaultAccount = res.flags.from;
            yield (0, checks_1.newCheckBuilder)(this).isAccount(res.flags.from).runChecks();
            const publicKey = res.flags.publicKey;
            const accounts = yield this.kit.contracts.getAccounts();
            yield (0, cli_1.displaySendTx)('RegisterDataEncryptionKey', accounts.setAccountDataEncryptionKey((0, address_1.ensureLeading0x)(publicKey)));
        });
    }
}
exports.default = RegisterDataEncryptionKey;
RegisterDataEncryptionKey.description = 'Register a data encryption key for an account on chain. This key can be used to encrypt data to you such as offchain metadata or transaction comments';
RegisterDataEncryptionKey.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({
        required: true,
        description: 'Addess of the account to set the data encryption key for',
    }), publicKey: command_1.flags.string({
        required: true,
        description: 'The public key you want to register',
    }) });
RegisterDataEncryptionKey.examples = [
    'register-data-encryption-key --publicKey 0x...  --from 0x47e172F6CfB6c7D01C1574fa3E2Be7CC73269D95',
];
//# sourceMappingURL=register-data-encryption-key.js.map