"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_1 = require("../../utils/command");
class SetWallet extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(SetWallet);
            this.kit.defaultAccount = res.flags.account;
            const accounts = yield this.kit.contracts.getAccounts();
            yield (0, checks_1.newCheckBuilder)(this).isAccount(res.flags.account).runChecks();
            if (res.flags.signature !== undefined) {
                try {
                    accounts.parseSignatureOfAddress(res.flags.account, res.flags.signer, res.flags.signature);
                }
                catch (error) {
                    console.error('Error: Failed to parse signature');
                }
                yield (0, cli_1.displaySendTx)('setWalletAddress', accounts.setWalletAddress(res.flags.wallet, accounts.parseSignatureOfAddress(res.flags.account, res.flags.signer, res.flags.signature)));
            }
            else {
                yield (0, cli_1.displaySendTx)('setWalletAddress', accounts.setWalletAddress(res.flags.wallet));
            }
        });
    }
}
exports.default = SetWallet;
SetWallet.description = "Sets the wallet of a registered account on-chain. An account's wallet is an optional wallet associated with an account. Can be set by the account or an account's signer.";
SetWallet.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { account: command_1.Flags.address({ required: true }), wallet: command_1.Flags.address({ required: true }), signature: command_1.Flags.proofOfPossession({
        required: false,
        description: 'Signature (a.k.a. proof-of-possession) of the signer key',
    }), signer: command_1.Flags.address({
        required: false,
        default: '',
        description: 'Address of the signer key to verify proof of possession.',
    }) });
SetWallet.args = [];
SetWallet.examples = [
    'set-wallet --account 0x5409ed021d9299bf6814279a6a1411a7e866a631 --wallet 0x5409ed021d9299bf6814279a6a1411a7e866a631',
    'set-wallet --account 0x5409ed021d9299bf6814279a6a1411a7e866a631 --wallet 0x5409ed021d9299bf6814279a6a1411a7e866a631 --signer 0x0EdeDF7B1287f07db348997663EeEb283D70aBE7 --signature 0x1c5efaa1f7ca6484d49ccce76217e2fba0552c0b23462cff7ba646473bc2717ffc4ce45be89bd5be9b5d23305e87fc2896808467c4081d9524a84c01b89ec91ca3',
];
//# sourceMappingURL=set-wallet.js.map