"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Method = void 0;
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const command_2 = require("../../utils/command");
const DKG = require('./DKG.json');
var Method;
(function (Method) {
    Method["shares"] = "shares";
    Method["responses"] = "responses";
    Method["justifications"] = "justifications";
    Method["participants"] = "participants";
    Method["phase"] = "phase";
    Method["group"] = "group";
})(Method = exports.Method || (exports.Method = {}));
class DKGGet extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(DKGGet);
            const web3 = this.kit.connection.web3;
            const dkg = new web3.eth.Contract(DKG.abi, res.flags.address);
            const methodType = res.flags.method;
            switch (methodType) {
                case Method.shares: {
                    const data = yield dkg.methods.getShares().call();
                    this.log(JSON.stringify(data));
                    break;
                }
                case Method.responses: {
                    const data = yield dkg.methods.getResponses().call();
                    this.log(JSON.stringify(data));
                    break;
                }
                case Method.justifications: {
                    const data = yield dkg.methods.getJustifications().call();
                    this.log(JSON.stringify(data));
                    break;
                }
                case Method.participants: {
                    const data = yield dkg.methods.getParticipants().call();
                    this.log(JSON.stringify(data));
                    break;
                }
                case Method.phase: {
                    const phase = yield dkg.methods.inPhase().call();
                    this.log(`In phase: ${phase}`);
                    break;
                }
                case Method.group: {
                    const data = yield dkg.methods.getBlsKeys().call();
                    const group = { threshold: data[0], blsKeys: data[1] };
                    this.log(JSON.stringify(group));
                    break;
                }
            }
        });
    }
}
exports.default = DKGGet;
DKGGet.description = 'Gets data from the contract to run the next phase';
DKGGet.options = ['shares', 'responses', 'justifications', 'participants', 'phase', 'group'];
DKGGet.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { method: command_1.flags.enum({
        options: DKGGet.options,
        required: true,
        description: 'Getter method to call',
    }), address: command_2.Flags.address({ required: true, description: 'DKG Contract Address' }) });
//# sourceMappingURL=get.js.map