"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.otherValidatorTable = void 0;
const address_1 = require("@celo/utils/lib/address");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const list_1 = require("../validator/list");
exports.otherValidatorTable = {
    address: {},
    name: {},
    currentSigner: {},
    signer: {},
    changed: {},
};
class ElectionCurrent extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(ElectionCurrent);
            cli_ux_1.cli.action.start('Fetching currently elected Validators');
            const election = yield this.kit.contracts.getElection();
            const validators = yield this.kit.contracts.getValidators();
            const signers = yield election.getCurrentValidatorSigners();
            if (res.flags.valset) {
                const validatorList = yield Promise.all(signers.map((addr) => __awaiter(this, void 0, void 0, function* () {
                    const v = yield validators.getValidatorFromSigner(addr);
                    return Object.assign(Object.assign({}, v), { currentSigner: addr, changed: (0, address_1.eqAddress)(addr, v.signer) ? '' : 'CHANGING' });
                })));
                cli_ux_1.cli.action.stop();
                cli_ux_1.cli.table(validatorList, exports.otherValidatorTable, res.flags);
            }
            else {
                const validatorList = yield Promise.all(signers.map((addr) => validators.getValidatorFromSigner(addr)));
                cli_ux_1.cli.action.stop();
                cli_ux_1.cli.table(validatorList, list_1.validatorTable, res.flags);
            }
        });
    }
}
exports.default = ElectionCurrent;
ElectionCurrent.description = 'Outputs the set of validators currently participating in BFT to create blocks. An election is run to select the validator set at the end of every epoch.';
ElectionCurrent.flags = Object.assign(Object.assign(Object.assign({}, base_1.BaseCommand.flags), { valset: command_1.flags.boolean({
        description: 'Show currently used signers from valset (by default the authorized validator signers are shown). Useful for checking if keys have been rotated.',
    }) }), cli_ux_1.cli.table.flags());
//# sourceMappingURL=current.js.map