"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const contractkit_1 = require("@celo/contractkit");
const celo_tokens_1 = require("@celo/contractkit/lib/celo-tokens");
const command_1 = require("@oclif/command");
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
const exchange_1 = require("../../utils/exchange");
const helpers_1 = require("../../utils/helpers");
const largeOrderPercentage = 1;
const deppegedPricePercentage = 20;
const stableTokenOptions = (0, helpers_1.enumEntriesDupWithLowercase)(Object.entries(contractkit_1.StableToken));
class ExchangeCelo extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(ExchangeCelo);
            const sellAmount = res.flags.value;
            const minBuyAmount = res.flags.forAtLeast;
            const stableToken = stableTokenOptions[res.flags.stableToken];
            let exchange;
            try {
                exchange = yield this.kit.contracts.getExchange(stableToken);
            }
            catch (_a) {
                (0, cli_1.failWith)(`The ${stableToken} token was not deployed yet`);
            }
            yield (0, checks_1.newCheckBuilder)(this).hasEnoughCelo(res.flags.from, sellAmount).runChecks();
            if (minBuyAmount.toNumber() === 0) {
                const check = yield (0, exchange_1.checkNotDangerousExchange)(this.kit, sellAmount, largeOrderPercentage, deppegedPricePercentage, true, celo_tokens_1.stableTokenInfos[stableToken]);
                if (!check) {
                    console.log('Cancelled');
                    return;
                }
            }
            const celoToken = yield this.kit.contracts.getGoldToken();
            yield (0, cli_1.displaySendTx)('increaseAllowance', celoToken.increaseAllowance(exchange.address, sellAmount.toFixed()));
            const exchangeTx = exchange.exchange(sellAmount.toFixed(), minBuyAmount.toFixed(), true);
            // Set explicit gas based on github.com/celo-org/celo-monorepo/issues/2541
            yield (0, cli_1.displaySendTx)('exchange', exchangeTx, { gas: 300000 });
        });
    }
}
exports.default = ExchangeCelo;
ExchangeCelo.description = 'Exchange CELO for StableTokens via the stability mechanism. (Note: this is the equivalent of the old exchange:gold)';
ExchangeCelo.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({ required: true, description: 'The address with CELO to exchange' }), value: command_2.Flags.wei({
        required: true,
        description: 'The value of CELO to exchange for a StableToken',
    }), forAtLeast: command_2.Flags.wei({
        description: 'Optional, the minimum value of StableTokens to receive in return',
        default: new bignumber_js_1.default(0),
    }), stableToken: command_1.flags.enum({
        options: Object.keys(stableTokenOptions),
        description: 'Name of the stable to receive',
        default: 'cUSD',
    }) });
ExchangeCelo.args = [];
ExchangeCelo.examples = [
    'celo --value 5000000000000 --from 0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d',
    'celo --value 5000000000000 --forAtLeast 100000000000000 --from 0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d --stableToken cStableTokenSymbol',
];
//# sourceMappingURL=celo.js.map