"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const contractkit_1 = require("@celo/contractkit");
const command_1 = require("@oclif/command");
const exchange_stable_base_1 = __importDefault(require("../../exchange-stable-base"));
const helpers_1 = require("../../utils/helpers");
const stableTokenOptions = (0, helpers_1.enumEntriesDupWithLowercase)(Object.entries(contractkit_1.StableToken));
class ExchangeStable extends exchange_stable_base_1.default {
    init() {
        const _super = Object.create(null, {
            init: { get: () => super.init }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(ExchangeStable);
            const stableName = res.flags.stableToken;
            this._stableCurrency = stableTokenOptions[stableName];
            yield _super.init.call(this);
        });
    }
}
exports.default = ExchangeStable;
ExchangeStable.description = 'Exchange Stable Token for CELO via the stability mechanism';
ExchangeStable.flags = Object.assign(Object.assign({}, exchange_stable_base_1.default.flags), { stableToken: command_1.flags.enum({
        options: Object.keys(stableTokenOptions),
        description: 'Name of the stable token to be transfered',
    }) });
ExchangeStable.examples = [
    'stable --value 10000000000000 --from 0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d --stableToken cStableTokenSymbol',
    'stable --value 10000000000000 --forAtLeast 50000000000000 --from 0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d --stableToken cStableTokenSymbol',
];
//# sourceMappingURL=stable.js.map