"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("@ethereumjs/util");
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class Approve extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(Approve);
            const account = res.flags.from;
            const useMultiSig = res.flags.useMultiSig;
            const id = res.flags.proposalID;
            const hotfix = res.flags.hotfix;
            this.kit.defaultAccount = account;
            const governance = yield this.kit.contracts.getGovernance();
            const governanceApproverMultiSig = useMultiSig
                ? yield governance.getApproverMultisig()
                : undefined;
            const approver = useMultiSig ? governanceApproverMultiSig.address : account;
            const checkBuilder = (0, checks_1.newCheckBuilder)(this)
                .isApprover(approver)
                .addConditionalCheck(`${account} is multisig signatory`, useMultiSig, () => governanceApproverMultiSig.isowner(account));
            let governanceTx;
            let logEvent;
            if (id) {
                if (yield governance.isQueued(id)) {
                    yield governance.dequeueProposalsIfReady().sendAndWaitForReceipt();
                }
                const governanceVersion = yield governance.version();
                yield checkBuilder
                    .proposalExists(id)
                    .proposalInStage(id, governanceVersion.storage === '1' && governanceVersion.major < 3
                    ? 'Approval'
                    : 'Referendum')
                    .addCheck(`${id} not already approved`, () => __awaiter(this, void 0, void 0, function* () { return !(yield governance.isApproved(id)); }))
                    .runChecks();
                governanceTx = yield governance.approve(id);
                logEvent = 'ProposalApproved';
            }
            else if (hotfix) {
                const hotfixBuf = (0, util_1.toBuffer)(hotfix);
                yield checkBuilder.hotfixNotExecuted(hotfixBuf).hotfixNotApproved(hotfixBuf).runChecks();
                governanceTx = governance.approveHotfix(hotfixBuf);
                logEvent = 'HotfixApproved';
            }
            else {
                (0, cli_1.failWith)('Proposal ID or hotfix must be provided');
            }
            const tx = useMultiSig
                ? yield governanceApproverMultiSig.submitOrConfirmTransaction(governance.address, governanceTx.txo)
                : governanceTx;
            yield (0, cli_1.displaySendTx)('approveTx', tx, {}, logEvent);
        });
    }
}
exports.default = Approve;
Approve.description = 'Approve a dequeued governance proposal (or hotfix)';
Approve.aliases = ['governance:approve', 'governance:approvehotfix'];
// Only authorized approvers need to know about this command.
Approve.hidden = true;
Approve.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { proposalID: command_1.flags.string({
        description: 'UUID of proposal to approve',
        exclusive: ['hotfix'],
    }), from: command_2.Flags.address({ required: true, description: "Approver's address" }), useMultiSig: command_1.flags.boolean({
        description: 'True means the request will be sent through multisig.',
    }), hotfix: command_1.flags.string({
        exclusive: ['proposalID'],
        description: 'Hash of hotfix proposal',
    }) });
Approve.examples = [
    'approve --proposalID 99 --from 0x5409ed021d9299bf6814279a6a1411a7e866a631',
    'approve --proposalID 99 --from 0x5409ed021d9299bf6814279a6a1411a7e866a631 --useMultiSig',
    'approve --hotfix 0xfcfc98ec3db7c56f0866a7149e811bf7f9e30c9d40008b0def497fcc6fe90649 --from 0xCc50EaC48bA71343dC76852FAE1892c6Bd2971DA --useMultiSig',
];
//# sourceMappingURL=approve.js.map