"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const proposals_1 = require("@celo/governance/lib/proposals");
const command_1 = require("@oclif/command");
const fs_extra_1 = require("fs-extra");
const base_1 = require("../../base");
const governance_1 = require("../../utils/governance");
class BuildProposal extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(BuildProposal);
            const builder = new proposals_1.ProposalBuilder(this.kit);
            if (res.flags.afterExecutingID) {
                yield (0, governance_1.addExistingProposalIDToBuilder)(this.kit, builder, res.flags.afterExecutingID);
            }
            else if (res.flags.afterExecutingProposal) {
                yield (0, governance_1.addExistingProposalJSONFileToBuilder)(builder, res.flags.afterExecutingProposal);
            }
            // TODO: optimize builder redundancies
            const promptBuilder = new proposals_1.InteractiveProposalBuilder(builder);
            const output = yield promptBuilder.promptTransactions();
            console.info(`Outputting proposal to ${res.flags.output}`);
            (0, fs_extra_1.writeFileSync)(res.flags.output, JSON.stringify(output));
            output.forEach((tx) => builder.addJsonTx(tx));
            const proposal = yield builder.build();
            yield (0, governance_1.checkProposal)(proposal, this.kit);
        });
    }
}
exports.default = BuildProposal;
BuildProposal.description = 'Interactively build a governance proposal';
BuildProposal.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { output: command_1.flags.string({
        required: false,
        description: 'Path to output',
        default: 'proposalTransactions.json',
    }), afterExecutingProposal: command_1.flags.string({
        required: false,
        description: 'Path to proposal which will be executed prior to proposal being built',
        exclusive: ['afterExecutingID'],
    }), afterExecutingID: command_1.flags.string({
        required: false,
        description: 'Governance proposal identifier which will be executed prior to proposal being built',
        exclusive: ['afterExecutingProposal'],
    }) });
BuildProposal.examples = ['build-proposal --output ./transactions.json'];
//# sourceMappingURL=build-proposal.js.map