"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const contractkit_1 = require("@celo/contractkit");
const fixidity_1 = require("@celo/utils/lib/fixidity");
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
const helpers_1 = require("../../utils/helpers");
const stableTokenOptions = (0, helpers_1.enumEntriesDupWithLowercase)(Object.entries(contractkit_1.StableToken));
class GetBuyAmount extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const grandaMento = yield this.kit.contracts.getGrandaMento();
            const res = this.parse(GetBuyAmount);
            const sellAmount = res.flags.value;
            const stableToken = stableTokenOptions[res.flags.stableToken];
            const sellCelo = res.flags.sellCelo === 'true';
            const stableTokenAddress = yield this.kit.celoTokens.getAddress(stableToken);
            const sortedOracles = yield this.kit.contracts.getSortedOracles();
            const celoStableTokenOracleRate = (yield sortedOracles.medianRate(stableTokenAddress)).rate;
            const buyAmount = yield grandaMento.getBuyAmount((0, fixidity_1.toFixed)(celoStableTokenOracleRate), sellAmount, sellCelo);
            (0, cli_1.printValueMap)({
                buyAmount,
            });
        });
    }
}
exports.default = GetBuyAmount;
GetBuyAmount.description = 'Gets the buy amount for a prospective Granda Mento exchange';
GetBuyAmount.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { value: command_2.Flags.wei({
        required: true,
        description: 'The value of the tokens to exchange',
    }), stableToken: command_1.flags.enum({
        required: true,
        options: Object.keys(stableTokenOptions),
        description: 'Name of the stable to receive or send',
        default: 'cUSD',
    }), sellCelo: command_1.flags.enum({
        options: ['true', 'false'],
        required: true,
        description: 'Sell or buy CELO',
    }) });
//# sourceMappingURL=get-buy-amount.js.map