"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Attestations_1 = require("@celo/contractkit/lib/wrappers/Attestations");
const async_1 = require("@celo/utils/lib/async");
const chalk_1 = __importDefault(require("chalk"));
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
class AttestationServicesCurrent extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(AttestationServicesCurrent);
            cli_ux_1.cli.action.start('Fetching currently elected Validators');
            const election = yield this.kit.contracts.getElection();
            const validators = yield this.kit.contracts.getValidators();
            const attestations = yield this.kit.contracts.getAttestations();
            const signers = yield election.getCurrentValidatorSigners();
            const validatorList = yield Promise.all(signers.map((addr) => validators.getValidatorFromSigner(addr)));
            const validatorInfo = yield (0, async_1.concurrentMap)(5, validatorList, attestations.getAttestationServiceStatus.bind(attestations));
            cli_ux_1.cli.action.stop();
            cli_ux_1.cli.table(validatorInfo.sort((a, b) => {
                if (a.affiliation === b.affiliation) {
                    return 0;
                }
                else if (a.affiliation === null) {
                    return 1;
                }
                else if (b.affiliation === null) {
                    return -1;
                }
                return a.affiliation.toLowerCase().localeCompare(b.affiliation.toLowerCase());
            }), {
                address: {},
                affiliation: {},
                name: {},
                state: {
                    get: (r) => {
                        switch (r.state) {
                            case Attestations_1.AttestationServiceStatusState.NoMetadataURL:
                            case Attestations_1.AttestationServiceStatusState.InvalidMetadata:
                            case Attestations_1.AttestationServiceStatusState.UnreachableAttestationService:
                            case Attestations_1.AttestationServiceStatusState.WrongAccount:
                            case Attestations_1.AttestationServiceStatusState.Unhealthy:
                            case Attestations_1.AttestationServiceStatusState.InvalidAttestationServiceURL:
                                return chalk_1.default.red(r.state);
                            case Attestations_1.AttestationServiceStatusState.Valid:
                                return chalk_1.default.green(r.state);
                            case Attestations_1.AttestationServiceStatusState.NoAttestationSigner:
                                return r.state;
                            default:
                                return chalk_1.default.yellow(r.state);
                        }
                    },
                },
                version: {},
                attestationServiceURL: {},
                smsProviders: {},
            }, res.flags);
        });
    }
}
exports.default = AttestationServicesCurrent;
AttestationServicesCurrent.description = "Outputs the set of validators currently participating in BFT and which ones are participating in Celo's lightweight identity protocol";
AttestationServicesCurrent.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), cli_ux_1.cli.table.flags());
//# sourceMappingURL=current-attestation-services.js.map