"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const identity_1 = require("@celo/identity");
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
class GetAttestations extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(GetAttestations);
            const phoneNumber = res.flags.phoneNumber;
            const account = res.flags.from;
            let identifier = res.flags.identifier;
            let pepper = res.flags.pepper;
            if (!account && !pepper && !identifier) {
                throw Error('Must specify either --from or --pepper or --identifier');
            }
            const network = res.flags.network;
            const attestationsContract = yield this.kit.contracts.getAttestations();
            const accountsContract = yield this.kit.contracts.getAccounts();
            if (!identifier) {
                if (!phoneNumber) {
                    throw Error('Must specify phoneNumber if identifier not provided');
                }
                // Get Phone number pepper
                // Needs a balance to perform query
                if (!pepper) {
                    pepper = yield this.getPhoneNumberPepper(this.kit, phoneNumber, account, network);
                    console.log('Pepper: ' + pepper);
                }
                const computedIdentifier = this.kit.connection.web3.utils.soliditySha3({
                    type: 'string',
                    value: 'tel://' + phoneNumber + '__' + pepper,
                });
                identifier = computedIdentifier;
                console.log('Identifier: ' + identifier);
            }
            const accounts = yield attestationsContract.lookupAccountsForIdentifier(identifier);
            accounts.forEach((accountAddress) => __awaiter(this, void 0, void 0, function* () {
                console.log('Account address: ' + accountAddress);
                console.log('\tWallet address: ' + (yield accountsContract.getWalletAddress(accountAddress)));
                console.log('\tData-Encryption Key: ' + (yield accountsContract.getDataEncryptionKey(accountAddress)));
            }));
        });
    }
    getPhoneNumberPepper(kit, phoneNumber, account, network = 'mainnet') {
        return __awaiter(this, void 0, void 0, function* () {
            console.log('Using network: ' + network);
            const authSigner = {
                authenticationMethod: identity_1.OdisUtils.Query.AuthenticationMethod.WALLET_KEY,
                contractKit: kit,
            };
            const ret = yield identity_1.OdisUtils.PhoneNumberIdentifier.getPhoneNumberIdentifier(phoneNumber, account, authSigner, identity_1.OdisUtils.Query.getServiceContext(network));
            return ret.pepper;
        });
    }
}
exports.default = GetAttestations;
GetAttestations.description = "Looks up attestations associated with the provided phone number. If a pepper is not provided, it uses the --from account's balance to query the pepper.";
GetAttestations.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { phoneNumber: command_1.flags.string({
        required: false,
        description: 'Phone number to check attestations for',
    }), from: command_1.flags.string({
        required: false,
        description: 'Account whose balance to use for querying ODIS for the pepper lookup',
    }), pepper: command_1.flags.string({
        required: false,
        description: 'ODIS phone number pepper',
    }), identifier: command_1.flags.string({
        required: false,
        description: 'On-chain identifier',
    }), network: command_1.flags.string({
        required: false,
        description: 'The ODIS service to hit: mainnet, alfajores, alfajoresstaging',
    }) });
GetAttestations.examples = [
    'get-attestations --phoneNumber +15555555555 --from 0x47e172F6CfB6c7D01C1574fa3E2Be7CC73269D95',
    'get-attestations --phoneNumber +15555555555 --pepper XgnKVpplZc0p1',
    'get-attestations --identifier 0x4952c9db9c283a62721b13f56c4b5e84a438e2569af3de21cb3440efa8840872',
];
//# sourceMappingURL=get-attestations.js.map