"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const identity_1 = require("@celo/identity");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class IdentifierQuery extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(IdentifierQuery);
            const { phoneNumber, from, context } = flags;
            yield (0, checks_1.newCheckBuilder)(this).isValidAddress(flags.from).runChecks();
            cli_ux_1.cli.action.start('Querying ODIS for identifier');
            const authSigner = {
                authenticationMethod: identity_1.OdisUtils.Query.AuthenticationMethod.WALLET_KEY,
                contractKit: this.kit,
            };
            const res = yield identity_1.OdisUtils.PhoneNumberIdentifier.getPhoneNumberIdentifier(phoneNumber, from, authSigner, identity_1.OdisUtils.Query.getServiceContext(context));
            cli_ux_1.cli.action.stop();
            (0, cli_1.printValueMap)({
                identifier: res.phoneHash,
                pepper: res.pepper,
            });
        });
    }
}
exports.default = IdentifierQuery;
IdentifierQuery.description = 'Queries ODIS for the on-chain identifier and pepper corresponding to a given phone number.';
IdentifierQuery.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({
        required: true,
        description: 'The address from which to perform the query',
    }), phoneNumber: command_2.Flags.phoneNumber({
        required: true,
        description: 'The phone number for which to query the identifier. Should be in e164 format with country code.',
    }), context: command_1.flags.string({
        required: false,
        description: 'mainnet (default), alfajores, or alfajoresstaging',
    }) });
IdentifierQuery.examples = [
    'identifier --phoneNumber +14151231234 --from 0x5409ed021d9299bf6814279a6a1411a7e866a631 --context alfajores',
];
//# sourceMappingURL=identifier.js.map