"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
const command_1 = require("../../utils/command");
class AttestationRewardsWithdraw extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(AttestationRewardsWithdraw);
            const [accounts, attestations] = yield Promise.all([
                this.kit.contracts.getAccounts(),
                this.kit.contracts.getAttestations(),
            ]);
            let tokenAddress = flags.tokenAddress;
            if (!tokenAddress) {
                tokenAddress = (yield this.kit.contracts.getStableToken()).address;
            }
            const accountAddress = yield accounts.signerToAccount(flags.from);
            const pendingWithdrawals = yield attestations.getPendingWithdrawals(tokenAddress, accountAddress);
            if (!pendingWithdrawals.gt(0)) {
                console.info('No pending rewards for this token address');
                return;
            }
            cli_ux_1.cli.action.start(`Withdrawing ${pendingWithdrawals.toString()} rewards to ${accountAddress}`);
            yield (0, cli_1.displaySendTx)('withdraw', attestations.withdraw(tokenAddress), { from: flags.from });
            cli_ux_1.cli.action.stop();
        });
    }
}
exports.default = AttestationRewardsWithdraw;
AttestationRewardsWithdraw.description = 'Withdraw accumulated attestation rewards for a given currency';
AttestationRewardsWithdraw.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_1.Flags.address({
        required: true,
        description: 'Address to withdraw from. Can be the attestation signer address or the underlying account address',
    }), tokenAddress: command_1.Flags.address({
        description: 'The address of the token that will be withdrawn. Defaults to cUSD',
    }) });
//# sourceMappingURL=withdraw-attestation-rewards.js.map