"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const bignumber_js_1 = require("bignumber.js");
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class MultiSigTransfer extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { args, flags: { to, sender, from, amount, transferFrom }, } = this.parse(MultiSigTransfer);
            const amountBN = new bignumber_js_1.BigNumber(amount);
            const celoToken = yield this.kit.contracts.getGoldToken();
            const multisig = yield this.kit.contracts.getMultiSig(args.address);
            let transferTx;
            if (transferFrom) {
                if (!sender)
                    this.error("Must submit 'sender' when submitting TransferFrom tx");
                // @ts-ignore - function will accept BigNumber
                transferTx = celoToken.transferFrom(sender, to, amountBN);
            }
            else {
                // @ts-ignore - function will accept BigNumber
                transferTx = celoToken.transfer(to, amountBN);
            }
            const multiSigTx = yield multisig.submitOrConfirmTransaction(celoToken.address, transferTx.txo);
            yield (0, cli_1.displaySendTx)('submitOrApproveTransfer', multiSigTx, { from }, 'tx Sent');
        });
    }
}
exports.default = MultiSigTransfer;
MultiSigTransfer.description = 'Ability to approve CELO transfers to and from multisig. Submit transaction or approve a matching existing transaction';
MultiSigTransfer.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { to: command_2.Flags.address({ required: true, description: 'Recipient of transfer' }), amount: command_1.flags.string({ required: true, description: 'Amount to transfer, e.g. 10e18' }), transferFrom: command_1.flags.boolean({
        description: 'Perform transferFrom instead of transfer in the ERC-20 interface',
    }), sender: command_2.Flags.address({ description: 'Identify sender if performing transferFrom' }), from: command_2.Flags.address({
        required: true,
        description: 'Account transferring value to the recipient',
    }) });
MultiSigTransfer.args = [command_2.Args.address('address')];
MultiSigTransfer.examples = [
    'transfer <multiSigAddr> --to 0x5409ed021d9299bf6814279a6a1411a7e866a631 --amount 200000e18 --from 0x123abc',
    'transfer <multiSigAddr> --transferFrom --sender 0x123abc --to 0x5409ed021d9299bf6814279a6a1411a7e866a631 --amount 200000e18 --from 0x123abc',
];
//# sourceMappingURL=transfer.js.map