"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@celo/base");
const contractkit_1 = require("@celo/contractkit");
const ICeloVersionedContract_1 = require("@celo/contractkit/lib/generated/ICeloVersionedContract");
const Proxy_1 = require("@celo/contractkit/lib/generated/Proxy");
const cli_ux_1 = require("cli-ux");
const base_2 = require("../../base");
const UNVERSIONED_CONTRACTS = [
    contractkit_1.CeloContract.Registry,
    contractkit_1.CeloContract.FeeCurrencyWhitelist,
    contractkit_1.CeloContract.Freezer,
];
const UNPROXIED_CONTRACTS = [];
class Contracts extends base_2.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(Contracts);
            const addressMapping = yield this.kit.registry.addressMapping();
            const contractInfo = yield (0, base_1.concurrentMap)(4, Array.from(addressMapping.entries()), ([contract, proxy]) => __awaiter(this, void 0, void 0, function* () {
                // skip implementation check for unproxied contract
                const implementation = UNPROXIED_CONTRACTS.includes(contract)
                    ? 'NONE'
                    : yield (0, Proxy_1.newProxy)(this.kit.web3, proxy).methods._getImplementation().call();
                // skip version check for unversioned contracts
                let version;
                if (UNVERSIONED_CONTRACTS.includes(contract)) {
                    version = 'NONE';
                }
                else {
                    const raw = yield (0, ICeloVersionedContract_1.newICeloVersionedContract)(this.kit.web3, implementation)
                        .methods.getVersionNumber()
                        .call();
                    version = `${raw[0]}.${raw[1]}.${raw[2]}.${raw[3]}`;
                }
                const balances = yield this.kit.celoTokens.balancesOf(proxy);
                return {
                    contract,
                    proxy,
                    implementation,
                    version,
                    balances,
                };
            }));
            const tokenBalanceColumns = {};
            yield this.kit.celoTokens.forEachCeloToken((token) => (tokenBalanceColumns[token.symbol] = {
                header: token.symbol,
                get: (i) => {
                    const balance = i.balances[token.symbol];
                    return balance.isZero() ? '0' : balance.toExponential(3);
                },
            }));
            cli_ux_1.cli.table(contractInfo, Object.assign({ contract: { get: (i) => i.contract }, proxy: { get: (i) => i.proxy }, implementation: { get: (i) => i.implementation }, version: {
                    get: (i) => i.version,
                } }, tokenBalanceColumns), Object.assign({ sort: 'contract' }, res.flags));
        });
    }
}
exports.default = Contracts;
Contracts.description = 'Lists Celo core contracts and their addesses.';
Contracts.flags = Object.assign(Object.assign({}, base_2.BaseCommand.flags), cli_ux_1.cli.table.flags());
//# sourceMappingURL=contracts.js.map