"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const cli_1 = require("../../utils/cli");
class Info extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(Info);
            const blockNumber = yield this.kit.connection.getBlockNumber();
            const latestEpochNumber = yield this.kit.getEpochNumberOfBlock(blockNumber);
            const epochSize = yield this.kit.getEpochSize();
            const fetchEpochInfo = (epochNumber) => __awaiter(this, void 0, void 0, function* () {
                return ({
                    number: epochNumber,
                    start: yield this.kit.getFirstBlockNumberForEpoch(epochNumber),
                    end: yield this.kit.getLastBlockNumberForEpoch(epochNumber),
                });
            });
            const n = res.flags.lastN;
            const epochs = [];
            for (let i = latestEpochNumber; i > latestEpochNumber - n; i--) {
                epochs.push(yield fetchEpochInfo(i));
            }
            (0, cli_1.printValueMapRecursive)({
                blockNumber,
                epochSize,
                epochs: epochs.length === 1 ? epochs[0] : epochs,
            });
        });
    }
}
exports.default = Info;
Info.description = 'View general network information such as the current block number';
Info.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { lastN: command_1.flags.integer({
        char: 'n',
        description: 'Fetch info about the last n epochs',
        required: false,
        default: 1,
    }) });
//# sourceMappingURL=info.js.map