"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const prompts_1 = __importDefault(require("prompts"));
const cli_1 = require("../../utils/cli");
const release_gold_base_1 = require("../../utils/release-gold-base");
class AdminRevoke extends release_gold_base_1.ReleaseGoldBaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const { flags: _flags } = this.parse(AdminRevoke);
            if (!_flags.yesreally) {
                const response = yield (0, prompts_1.default)({
                    type: 'confirm',
                    name: 'confirmation',
                    message: 'Are you sure you want to revoke this contract? (y/n)',
                });
                if (!response.confirmation) {
                    console.info('Aborting due to user response');
                    process.exit(0);
                }
            }
            this.kit.defaultAccount = yield this.releaseGoldWrapper.getReleaseOwner();
            const isRevoked = yield this.releaseGoldWrapper.isRevoked();
            if (!isRevoked) {
                yield (0, cli_1.displaySendTx)('releasegold: revokeBeneficiary', this.releaseGoldWrapper.revokeBeneficiary(), undefined, 'ReleaseScheduleRevoked');
            }
            const accounts = yield this.kit.contracts.getAccounts();
            const isAccount = yield accounts.isAccount(this.contractAddress);
            if (isAccount) {
                // rotate vote signers
                let voteSigner = yield accounts.getVoteSigner(this.contractAddress);
                if (voteSigner !== this.contractAddress) {
                    const password = 'bad_password';
                    voteSigner = yield this.web3.eth.personal.newAccount(password);
                    yield this.web3.eth.personal.unlockAccount(voteSigner, password, 1000);
                    const pop = yield accounts.generateProofOfKeyPossession(this.contractAddress, voteSigner);
                    yield (0, cli_1.displaySendTx)('accounts: rotateVoteSigner', yield this.releaseGoldWrapper.authorizeVoteSigner(voteSigner, pop), undefined, 'VoteSignerAuthorized');
                }
                const election = yield this.kit.contracts.getElection();
                const electionVotes = yield election.getTotalVotesByAccount(this.contractAddress);
                const isElectionVoting = electionVotes.isGreaterThan(0);
                // handle election votes
                if (isElectionVoting) {
                    const txos = yield this.releaseGoldWrapper.revokeAllVotesForAllGroups();
                    for (const txo of txos) {
                        yield (0, cli_1.displaySendTx)('election: revokeVotes', txo, { from: voteSigner }, [
                            'ValidatorGroupPendingVoteRevoked',
                            'ValidatorGroupActiveVoteRevoked',
                        ]);
                    }
                }
                const governance = yield this.kit.contracts.getGovernance();
                const isGovernanceVoting = yield governance.isVoting(this.contractAddress);
                // handle governance votes
                if (isGovernanceVoting) {
                    const isUpvoting = yield governance.isUpvoting(this.contractAddress);
                    if (isUpvoting) {
                        yield (0, cli_1.displaySendTx)('governance: revokeUpvote', yield governance.revokeUpvote(this.contractAddress), { from: voteSigner }, 'ProposalUpvoteRevoked');
                    }
                    const isVotingReferendum = yield governance.isVotingReferendum(this.contractAddress);
                    if (isVotingReferendum) {
                        yield (0, cli_1.displaySendTx)('governance: revokeVotes', governance.revokeVotes(), { from: voteSigner }, 'ProposalVoteRevoked');
                    }
                }
                yield (0, cli_1.displaySendTx)('releasegold: unlockAllGold', yield this.releaseGoldWrapper.unlockAllGold(), undefined, 'GoldUnlocked');
            }
            // rescue any cUSD balance
            const stabletoken = yield this.kit.contracts.getStableToken();
            const cusdBalance = yield stabletoken.balanceOf(this.contractAddress);
            if (cusdBalance.isGreaterThan(0)) {
                yield (0, cli_1.displaySendTx)('releasegold: rescueCUSD', this.releaseGoldWrapper.transfer(this.kit.defaultAccount, cusdBalance), undefined, 'Transfer');
            }
            // attempt to refund and finalize, surface pending withdrawals
            const remainingLockedGold = yield this.releaseGoldWrapper.getRemainingLockedBalance();
            if (remainingLockedGold.isZero()) {
                yield (0, cli_1.displaySendTx)('releasegold: refundAndFinalize', this.releaseGoldWrapper.refundAndFinalize(), undefined, 'ReleaseGoldInstanceDestroyed');
            }
            else {
                console.log('Some gold is still locked, printing pending withdrawals...');
                const lockedGold = yield this.kit.contracts.getLockedGold();
                const pendingWithdrawals = yield lockedGold.getPendingWithdrawals(this.contractAddress);
                pendingWithdrawals.forEach((w) => (0, cli_1.printValueMap)(w));
            }
        });
    }
}
exports.default = AdminRevoke;
AdminRevoke.hidden = true;
AdminRevoke.description = 'Take all possible steps to revoke given contract instance.';
AdminRevoke.flags = Object.assign(Object.assign({}, release_gold_base_1.ReleaseGoldBaseCommand.flags), { yesreally: command_1.flags.boolean({ description: 'Override interactive prompt to confirm revocation' }) });
AdminRevoke.args = [];
AdminRevoke.examples = ['admin-revoke --contract 0x5409ED021D9299bf6814279A6A1411A7e866A631'];
//# sourceMappingURL=admin-revoke.js.map