"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class DowntimeSlashCommand extends base_1.BaseCommand {
    run() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(DowntimeSlashCommand);
            const validatorsToSlash = (_a = res.flags.validators) !== null && _a !== void 0 ? _a : [res.flags.validator];
            const downtimeSlasher = yield this.kit.contracts.getDowntimeSlasher();
            const intervals = res.flags.beforeBlock
                ? yield downtimeSlasher.slashableDowntimeIntervalsBefore(res.flags.beforeBlock)
                : res.flags.intervals;
            const [startBlock, endBlock] = [intervals[0].start, intervals[intervals.length - 1].end];
            yield (0, checks_1.newCheckBuilder)(this)
                .addCheck(`provided intervals span slashableDowntime blocks `, () => __awaiter(this, void 0, void 0, function* () { return endBlock - startBlock + 1 >= (yield downtimeSlasher.slashableDowntime()); }))
                .addCheck(`bitmaps are set for intervals`, () => downtimeSlasher.isBitmapSetForIntervals(intervals), 'some bitmaps are not set, please use validator:set-bitmaps')
                .runChecks();
            for (const validator of validatorsToSlash) {
                yield (0, checks_1.newCheckBuilder)(this, validator)
                    .isSignerOrAccount()
                    .canSignValidatorTxs()
                    .signerAccountIsValidator()
                    .addCheck(`validator not already slashed for span`, () => __awaiter(this, void 0, void 0, function* () { return startBlock > (yield downtimeSlasher.lastSlashedBlock(validator)); }), `${validator} was already slashed`)
                    .addCheck('validator was down for intervals', () => downtimeSlasher.wasValidatorDownForIntervals(validator, intervals), `${validator} was not down`)
                    .runChecks();
                const tx = yield downtimeSlasher.slashValidator(validator, intervals);
                yield (0, cli_1.displaySendTx)('slash', tx, undefined, 'DowntimeSlashPerformed');
            }
        });
    }
}
exports.default = DowntimeSlashCommand;
DowntimeSlashCommand.description = 'Downtime slash a validator';
DowntimeSlashCommand.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({
        required: true,
        description: 'From address to perform the slash (reward recipient)',
    }), validator: command_2.Flags.address({
        description: 'Validator (signer or account) address',
        exclusive: ['validators'],
    }), validators: command_2.Flags.addressArray({
        description: 'Validator (signer or account) address list',
        exclusive: ['validator'],
    }), intervals: command_2.Flags.intRangeArray({
        description: 'Array of intervals, ordered by min start to max end',
        exclusive: ['beforeBlock'],
    }), beforeBlock: command_1.flags.integer({
        description: 'Slash for slashable downtime window before provided block',
        exclusive: ['intervals'],
    }) });
DowntimeSlashCommand.examples = [
    'downtime-slash \
    --from 0x47e172f6cfb6c7d01c1574fa3e2be7cc73269d95 \
    --validator 0xb7ef0985bdb4f19460A29d9829aA1514B181C4CD \
    --intervals "[100:150), [150:200)"',
    'downtime-slash \
    --from 0x47e172f6cfb6c7d01c1574fa3e2be7cc73269d95 \
    --validator 0xb7ef0985bdb4f19460A29d9829aA1514B181C4CD \
    --slashableDowntimeBeforeBlock 200',
];
//# sourceMappingURL=downtime-slash.js.map