"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_1 = require("../../base");
const checks_1 = require("../../utils/checks");
const cli_1 = require("../../utils/cli");
const command_2 = require("../../utils/command");
class SetBitmapsCommand extends base_1.BaseCommand {
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse(SetBitmapsCommand);
            const downtimeSlasher = yield this.kit.contracts.getDowntimeSlasher();
            const intervals = res.flags.slashableDowntimeBeforeLatest || res.flags.slashableDowntimeBeforeBlock
                ? yield downtimeSlasher.slashableDowntimeIntervalsBefore(res.flags.slashableDowntimeBeforeBlock)
                : res.flags.intervals;
            yield (0, checks_1.newCheckBuilder)(this)
                .addCheck('bitmaps are not already set for intervals', () => __awaiter(this, void 0, void 0, function* () { return !(yield downtimeSlasher.isBitmapSetForIntervals(intervals)); }))
                .runChecks();
            for (const interval of intervals) {
                const tx = downtimeSlasher.setBitmapForInterval(interval);
                yield (0, cli_1.displaySendTx)('setBitmap', tx, undefined, 'BitmapSetForInterval');
            }
        });
    }
}
exports.default = SetBitmapsCommand;
SetBitmapsCommand.description = 'Set validator signature bitmaps for provided intervals';
SetBitmapsCommand.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({
        required: true,
        description: 'From address to sign set bitmap transactions',
    }), slashableDowntimeBeforeBlock: command_1.flags.integer({
        description: 'Set all bitmaps for slashable downtime window before provided block',
        exclusive: ['intervals', 'slashableDowntimeBeforeLatest'],
    }), slashableDowntimeBeforeLatest: command_1.flags.boolean({
        description: 'Set all bitmaps for slashable downtime window before latest block',
        exclusive: ['intervals', 'slashableDowntimeBeforeBlock'],
    }), intervals: command_2.Flags.intRangeArray({
        description: 'Array of intervals, ordered by min start to max end',
        exclusive: ['beforeBlock'],
    }) });
SetBitmapsCommand.examples = [
    'set-bitmaps --from 0x47e172f6cfb6c7d01c1574fa3e2be7cc73269d95 --slashableDowntimeBeforeBlock 10000',
    'set-bitmaps --from 0x47e172f6cfb6c7d01c1574fa3e2be7cc73269d95 --intervals "[0:100], (100:200]"',
];
//# sourceMappingURL=set-bitmaps.js.map