"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const celo_tokens_1 = require("@celo/contractkit/lib/celo-tokens");
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const base_1 = require("./base");
const checks_1 = require("./utils/checks");
const cli_1 = require("./utils/cli");
const command_1 = require("./utils/command");
const exchange_1 = require("./utils/exchange");
const largeOrderPercentage = 1;
const deppegedPricePercentage = 20;
class ExchangeStableBase extends base_1.BaseCommand {
    constructor() {
        super(...arguments);
        this._stableCurrency = null;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse();
            const sellAmount = res.flags.value;
            const minBuyAmount = res.flags.forAtLeast;
            if (!this._stableCurrency) {
                throw new Error('Stable currency not set');
            }
            yield (0, checks_1.newCheckBuilder)(this)
                .hasEnoughStable(res.flags.from, sellAmount, this._stableCurrency)
                .runChecks();
            let stableToken;
            let exchange;
            try {
                stableToken = yield this.kit.contracts.getStableToken(this._stableCurrency);
                exchange = yield this.kit.contracts.getExchange(this._stableCurrency);
            }
            catch (_a) {
                (0, cli_1.failWith)(`The ${this._stableCurrency} token was not deployed yet`);
            }
            if (minBuyAmount.toNumber() === 0) {
                const check = yield (0, exchange_1.checkNotDangerousExchange)(this.kit, sellAmount, largeOrderPercentage, deppegedPricePercentage, false, celo_tokens_1.stableTokenInfos[this._stableCurrency]);
                if (!check) {
                    console.log('Cancelled');
                    return;
                }
            }
            yield (0, cli_1.displaySendTx)('increaseAllowance', stableToken.increaseAllowance(exchange.address, sellAmount.toFixed()));
            const exchangeTx = exchange.exchange(sellAmount.toFixed(), minBuyAmount.toFixed(), false);
            // Set explicit gas based on github.com/celo-org/celo-monorepo/issues/2541
            yield (0, cli_1.displaySendTx)('exchange', exchangeTx, { gas: 300000 });
        });
    }
}
exports.default = ExchangeStableBase;
ExchangeStableBase.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_1.Flags.address({
        required: true,
        description: 'The address with the Stable Token to exchange',
    }), value: command_1.Flags.wei({
        required: true,
        description: 'The value of Stable Tokens to exchange for CELO',
    }), forAtLeast: command_1.Flags.wei({
        description: 'Optional, the minimum value of CELO to receive in return',
        default: new bignumber_js_1.default(0),
    }) });
//# sourceMappingURL=exchange-stable-base.js.map