"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferStableBase = void 0;
const celo_tokens_1 = require("@celo/contractkit/lib/celo-tokens");
const command_1 = require("@oclif/command");
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const base_1 = require("./base");
const checks_1 = require("./utils/checks");
const cli_1 = require("./utils/cli");
const command_2 = require("./utils/command");
class TransferStableBase extends base_1.BaseCommand {
    constructor() {
        super(...arguments);
        this._stableCurrency = null;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = this.parse();
            const from = res.flags.from;
            const to = res.flags.to;
            const value = new bignumber_js_1.default(res.flags.value);
            if (!this._stableCurrency) {
                throw new Error('Stable currency not set');
            }
            let stableToken;
            try {
                stableToken = yield this.kit.contracts.getStableToken(this._stableCurrency);
            }
            catch (_a) {
                (0, cli_1.failWith)(`The ${this._stableCurrency} token was not deployed yet`);
            }
            // If gasCurrency is not set, use the transferring token
            if (!res.flags.gasCurrency) {
                yield this.kit.setFeeCurrency(celo_tokens_1.stableTokenInfos[this._stableCurrency].contract);
            }
            const tx = res.flags.comment
                ? stableToken.transferWithComment(to, value.toFixed(), res.flags.comment)
                : stableToken.transfer(to, value.toFixed());
            yield (0, checks_1.newCheckBuilder)(this)
                .hasEnoughStable(from, value, this._stableCurrency)
                .addConditionalCheck(`Account can afford transfer and gas paid in ${this._stableCurrency}`, this.kit.connection.defaultFeeCurrency === stableToken.address, () => __awaiter(this, void 0, void 0, function* () {
                const [gas, gasPrice, balance] = yield Promise.all([
                    tx.txo.estimateGas({ feeCurrency: stableToken.address }),
                    this.kit.connection.gasPrice(stableToken.address),
                    stableToken.balanceOf(from),
                ]);
                const gasValue = new bignumber_js_1.default(gas).times(gasPrice);
                return balance.gte(value.plus(gasValue));
            }), `Cannot afford transfer with ${this._stableCurrency} gasCurrency; try reducing value slightly or using gasCurrency=CELO`)
                .runChecks();
            yield (0, cli_1.displaySendTx)(res.flags.comment ? 'transferWithComment' : 'transfer', tx);
        });
    }
}
exports.TransferStableBase = TransferStableBase;
TransferStableBase.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { from: command_2.Flags.address({ required: true, description: 'Address of the sender' }), to: command_2.Flags.address({ required: true, description: 'Address of the receiver' }), value: command_1.flags.string({ required: true, description: 'Amount to transfer (in wei)' }), comment: command_1.flags.string({ description: 'Transfer comment' }) });
//# sourceMappingURL=transfer-stable-base.js.map