"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkNotDangerousExchange = exports.swapArguments = void 0;
const celo_tokens_1 = require("@celo/contractkit/lib/celo-tokens");
const cli_1 = require("./cli");
exports.swapArguments = [
    {
        name: 'sellAmount',
        required: true,
        description: 'the amount of sellToken (in wei) to sell',
    },
    {
        name: 'minBuyAmount',
        required: true,
        description: 'the minimum amount of buyToken (in wei) expected',
    },
    {
        name: 'from',
        required: true,
    },
];
function checkNotDangerousExchange(kit, amount, largeOrderPercentage, deppegedPricePercentage, buyBucket, stableTokenInfo = celo_tokens_1.stableTokenInfos[celo_tokens_1.StableToken.cUSD]) {
    return __awaiter(this, void 0, void 0, function* () {
        const oracles = yield kit.contracts.getSortedOracles();
        const exchange = yield kit.contracts.getExchange(stableTokenInfo.symbol);
        const oracleMedianRate = (yield oracles.medianRate(stableTokenInfo.contract)).rate;
        const buckets = yield exchange.getBuyAndSellBuckets(false);
        const chainRate = buckets[1].dividedBy(buckets[0]);
        let warningMessage;
        // XX% difference between rates
        if (Math.abs(oracleMedianRate.dividedBy(chainRate).toNumber() - 1) > deppegedPricePercentage) {
            const warningDeppegedPrice = `Warning ${stableTokenInfo.symbol} price here (i.e. on-chain) is depegged by >${deppegedPricePercentage}% from the oracle prices (i.e. exchange prices).`;
            warningMessage = warningDeppegedPrice;
        }
        // X% of the bucket
        const bucket = buyBucket ? buckets[1] : buckets[0];
        if (bucket.dividedBy(100 / largeOrderPercentage).isLessThanOrEqualTo(amount)) {
            const warningLargeOrder = 'Warning you are executing a large order, risk of price slippage i.e. getting an unfavorable exchange rate.';
            warningMessage = warningMessage ? `${warningMessage} ${warningLargeOrder}` : warningLargeOrder;
        }
        if (warningMessage) {
            const check = yield (0, cli_1.binaryPrompt)(`${warningMessage}. Are you sure you want to continue?`, true);
            return check;
        }
        return true;
    });
}
exports.checkNotDangerousExchange = checkNotDangerousExchange;
//# sourceMappingURL=exchange.js.map