"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addExistingProposalJSONFileToBuilder = exports.addExistingProposalIDToBuilder = exports.executeProposal = exports.checkProposal = void 0;
const connect_1 = require("@celo/connect");
const governance_1 = require("@celo/governance");
const chalk_1 = __importDefault(require("chalk"));
const fs_extra_1 = require("fs-extra");
function checkProposal(proposal, kit) {
    return __awaiter(this, void 0, void 0, function* () {
        const governance = yield kit.contracts.getGovernance();
        return tryProposal(proposal, kit, governance.address, true);
    });
}
exports.checkProposal = checkProposal;
function executeProposal(proposal, kit, from) {
    return __awaiter(this, void 0, void 0, function* () {
        return tryProposal(proposal, kit, from, false);
    });
}
exports.executeProposal = executeProposal;
function tryProposal(proposal, kit, from, call) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('Simulating proposal execution');
        let ok = true;
        for (const [i, tx] of proposal.entries()) {
            if (!tx.to) {
                continue;
            }
            try {
                if (call) {
                    yield kit.web3.eth.call({
                        to: tx.to,
                        from,
                        value: tx.value,
                        data: tx.input,
                    });
                }
                else {
                    const txRes = (0, connect_1.toTxResult)(kit.web3.eth.sendTransaction({ to: tx.to, from, value: tx.value, data: tx.input }));
                    yield txRes.waitReceipt();
                }
                console.log(chalk_1.default.green(`   ${chalk_1.default.bold('✔')}  Transaction ${i} success!`));
            }
            catch (err) {
                console.log(chalk_1.default.red(`   ${chalk_1.default.bold('✘')}  Transaction ${i} failure: ${err.toString()}`));
                ok = false;
            }
        }
        return ok;
    });
}
function addExistingProposalIDToBuilder(kit, builder, existingProposalID) {
    return __awaiter(this, void 0, void 0, function* () {
        const governance = yield kit.contracts.getGovernance();
        const proposalRaw = yield governance.getProposal(existingProposalID);
        return addProposalToBuilder(builder, yield (0, governance_1.proposalToJSON)(kit, proposalRaw));
    });
}
exports.addExistingProposalIDToBuilder = addExistingProposalIDToBuilder;
function addExistingProposalJSONFileToBuilder(builder, existingProposalPath) {
    return addProposalToBuilder(builder, (0, fs_extra_1.readJsonSync)(existingProposalPath));
}
exports.addExistingProposalJSONFileToBuilder = addExistingProposalJSONFileToBuilder;
function addProposalToBuilder(builder, existingProposal) {
    return __awaiter(this, void 0, void 0, function* () {
        // accounts for registry additions and caches in builder
        for (const tx of existingProposal) {
            yield builder.fromJsonTx(tx);
        }
        console.info(`After executing provided proposal, account for registry remappings: ${JSON.stringify(builder.registryAdditions, null, 2)}`);
    });
}
//# sourceMappingURL=governance.js.map