"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OffchainDataCommand = exports.StorageProviders = void 0;
const offchain_data_wrapper_1 = require("@celo/identity/lib/offchain-data-wrapper");
const storage_writers_1 = require("@celo/identity/lib/offchain/storage-writers");
const address_1 = require("@celo/utils/lib/address");
const command_1 = require("@oclif/command");
const base_1 = require("../base");
const command_2 = require("./command");
var StorageProviders;
(function (StorageProviders) {
    StorageProviders["AWS"] = "aws";
    StorageProviders["GCP"] = "gcp";
    StorageProviders["git"] = "git";
})(StorageProviders = exports.StorageProviders || (exports.StorageProviders = {}));
class OffchainDataCommand extends base_1.BaseCommand {
    init() {
        const _super = Object.create(null, {
            init: { get: () => super.init }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.init.call(this);
            const { flags: { provider, directory, bucket, privateKey }, } = this.parse();
            const from = (0, address_1.privateKeyToAddress)(privateKey);
            this.offchainDataWrapper = new offchain_data_wrapper_1.BasicDataWrapper(from, this.kit);
            this.offchainDataWrapper.storageWriter =
                provider === StorageProviders.GCP
                    ? new storage_writers_1.GoogleStorageWriter(directory, bucket)
                    : provider === StorageProviders.AWS
                        ? new storage_writers_1.AwsStorageWriter(directory, bucket)
                        : provider === StorageProviders.git
                            ? new storage_writers_1.GitStorageWriter(directory)
                            : new storage_writers_1.LocalStorageWriter(directory);
        });
    }
}
exports.OffchainDataCommand = OffchainDataCommand;
OffchainDataCommand.flags = Object.assign(Object.assign({}, base_1.BaseCommand.flags), { directory: command_1.flags.string({
        parse: command_2.parsePath,
        default: '.',
        description: 'To which directory data should be written',
    }), provider: command_1.flags.enum({
        options: ['git', 'aws', 'gcp'],
        description: 'If the CLI should attempt to push to the cloud',
    }), bucket: command_1.flags.string({
        dependsOn: ['provider'],
        description: 'If using a GCP or AWS storage bucket this parameter is required',
    }) });
//# sourceMappingURL=off-chain-data.js.map